@@ -1,6 +1,6 @@
 use std::path::{Path, PathBuf};
 use std::fs;
-use std::io::{Error, Read, Write};
+use std::io::{Error, Read};
 
 /// Controls the size of the buffers for reading/writing to files.
 pub const BUFFER_SIZE: usize = 8 * 1024; // 8K seems to be the best buffer size.
@@ -25,16 +25,8 @@ pub struct DiskBuffer {
 
 impl DiskBuffer {
     // Create a new `DiskBuffer` from a `Path`.
-    pub fn new(path: &Path) -> DiskBuffer { DiskBuffer { path: path.to_owned() } }
-
-    /// Transform the `DiskBuffer` into a `DiskBufferWriter`.
-    pub fn write(self) -> Result<DiskBufferWriter, Error> {
-        fs::OpenOptions::new().create(true).write(true).open(&self.path)?;
-        Ok(DiskBufferWriter {
-            data:     [b'\0'; BUFFER_SIZE],
-            capacity: 0,
-            path:     self.path,
-        })
+    pub fn new<P: AsRef<Path>>(path: P) -> DiskBuffer {
+        DiskBuffer { path: path.as_ref().to_owned() }
     }
 
     /// Transform the `DiskBuffer` into a `DiskBufferReader`
@@ -81,56 +73,6 @@ impl DiskBufferReader {
     }
 }
 
-/// A `DiskBufferWriter` only contains methods for buffering writes to a file.
-pub struct DiskBufferWriter {
-    pub data:     [u8; BUFFER_SIZE],
-    pub capacity: usize,
-    pub path:     PathBuf,
-}
-
-impl DiskBufferTrait for DiskBufferWriter {
-    fn clear(&mut self) { self.capacity = 0; }
-    fn get_ref(&self) -> &[u8] { &self.data[0..self.capacity] }
-    fn is_empty(&self) -> bool { self.capacity == 0 }
-}
-
-impl DiskBufferWriter {
-    /// Write a byte slice to the buffer and mark the new size.
-    pub fn write(&mut self, data: &[u8]) -> Result<(), Error> {
-        let cap = data.len();
-        if cap + self.capacity > BUFFER_SIZE {
-            fs::OpenOptions::new().write(true).append(true).open(&self.path)
-                .and_then(|mut file| file.write(self.get_ref()))?;
-            self.clear();
-        }
-        self.data[self.capacity..self.capacity + cap].clone_from_slice(data);
-        self.capacity += cap;
-        Ok(())
-    }
-
-    /// Append an individual byte to the buffer, typically a space or newline.
-    pub fn write_byte(&mut self, data: u8) -> Result<(), Error> {
-        if self.capacity + 1 > BUFFER_SIZE {
-            fs::OpenOptions::new().write(true).append(true).open(&self.path)
-                .and_then(|mut file| file.write(self.get_ref()))?;
-            self.clear();
-        }
-        self.data[self.capacity] = data;
-        self.capacity += 1;
-        Ok(())
-    }
-
-    /// If data has not yet been written to the disk, flush it's contents.
-    pub fn flush(&mut self) -> Result<usize, Error> {
-        if !self.is_empty() {
-            return fs::OpenOptions::new().write(true).append(true).open(&self.path)
-                .and_then(|mut file| file.write(self.get_ref()));
-        }
-        self.capacity = 0;
-        Ok(0)
-    }
-}
-
 #[test]
 fn test_disk_buffer_reader_simple() {
     let file = include_bytes!("../../tests/buffer.dat");
